Skip to contents

Methods to combine chains from fitted stan_nma model objects, or mcmc_array 3D MCMC arrays. cbind.stan_nma() is an alias for bind_chains().

Usage

bind_chains(...)

# S3 method for class 'stan_nma'
cbind(...)

# S3 method for class 'mcmc_array'
cbind(...)

Arguments

...

Multiple fitted stan_nma model objects (for bind_chains()) or mcmc_array arrays (for cbind.mcmc_array()). bind_chains() also accepts a single list as input, containing the objects to combine.

Value

A stan_nma or mcmc_array object.

Details

Objects to combine must have the same number of iterations, warmup, and thinning, and all parameter names must match. For bind_chains(), this means that both the model specification and input data must be the same.